package com.ruoyi.model.mapper;

import java.util.List;
import com.ruoyi.model.domain.AppletAnswer;

/**
 * 基本考核答案Mapper接口
 * 
 * @author ruoyi
 * @date 2025-03-28
 */
public interface AppletAnswerMapper 
{
    /**
     * 查询基本考核答案
     * 
     * @param id 基本考核答案主键
     * @return 基本考核答案
     */
    public AppletAnswer selectAppletAnswerById(Long id);

    /**
     * 查询基本考核答案列表
     * 
     * @param appletAnswer 基本考核答案
     * @return 基本考核答案集合
     */
    public List<AppletAnswer> selectAppletAnswerList(AppletAnswer appletAnswer);

    /**
     * 新增基本考核答案
     * 
     * @param appletAnswer 基本考核答案
     * @return 结果
     */
    public int insertAppletAnswer(AppletAnswer appletAnswer);

    /**
     * 修改基本考核答案
     * 
     * @param appletAnswer 基本考核答案
     * @return 结果
     */
    public int updateAppletAnswer(AppletAnswer appletAnswer);

    /**
     * 删除基本考核答案
     * 
     * @param id 基本考核答案主键
     * @return 结果
     */
    public int deleteAppletAnswerById(Long id);

    /**
     * 批量删除基本考核答案
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteAppletAnswerByIds(Long[] ids);
}
