package com.ruoyi.model.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.model.domain.AppletAnswer;
import com.ruoyi.model.service.IAppletAnswerService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 基本考核答案Controller
 * 
 * @author ruoyi
 * @date 2025-03-28
 */
@RestController
@RequestMapping("/model/AppletAnswer")
public class AppletAnswerController extends BaseController
{
    @Autowired
    private IAppletAnswerService appletAnswerService;

    /**
     * 查询基本考核答案列表
     */
    @PreAuthorize("@ss.hasPermi('model:AppletAnswer:list')")
    @GetMapping("/list")
    public TableDataInfo list(AppletAnswer appletAnswer)
    {
        startPage();
        List<AppletAnswer> list = appletAnswerService.selectAppletAnswerList(appletAnswer);
        return getDataTable(list);
    }

    /**
     * 导出基本考核答案列表
     */
    @PreAuthorize("@ss.hasPermi('model:AppletAnswer:export')")
    @Log(title = "基本考核答案", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, AppletAnswer appletAnswer)
    {
//        List<AppletAnswer> list = appletAnswerService.selectAppletAnswerList(appletAnswer);
//        ExcelUtil<AppletAnswer> util = new ExcelUtil<AppletAnswer>(AppletAnswer.class);
//        util.exportExcel(response, list, "基本考核答案数据");
    }

    /**
     * 获取基本考核答案详细信息
     */
    @PreAuthorize("@ss.hasPermi('model:AppletAnswer:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(appletAnswerService.selectAppletAnswerById(id));
    }

    /**
     * 新增基本考核答案
     */
    @PreAuthorize("@ss.hasPermi('model:AppletAnswer:add')")
    @Log(title = "基本考核答案", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody AppletAnswer appletAnswer)
    {
        return toAjax(appletAnswerService.insertAppletAnswer(appletAnswer));
    }

    /**
     * 修改基本考核答案
     */
    @PreAuthorize("@ss.hasPermi('model:AppletAnswer:edit')")
    @Log(title = "基本考核答案", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody AppletAnswer appletAnswer)
    {
        return toAjax(appletAnswerService.updateAppletAnswer(appletAnswer));
    }

    /**
     * 删除基本考核答案
     */
    @PreAuthorize("@ss.hasPermi('model:AppletAnswer:remove')")
    @Log(title = "基本考核答案", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(appletAnswerService.deleteAppletAnswerByIds(ids));
    }
}
